@@ -1,6 +1,6 @@
 package HTML::Display::Win32;
 use vars qw($VERSION);
-$VERSION='0.02';
+$VERSION='0.03';
 
 =head1 NAME
 
@@ -17,7 +17,7 @@ HTML::Display::Win32 - display an URL through the default application for HTML
 
 =head1 BUGS
 
-Currently does not work. 
+Currently does not work.
 
 Making it work will need either munging the tempfilename to
 become ".html", or looking through the registry whether we find
@@ -27,6 +27,9 @@ a suitable application there.
 
 use base 'HTML::Display::TempFile';
 
-sub browsercmd { 'start "%s" "%s"' };
+sub browsercmd { 
+  # cmd.exe needs two arguments, command.com needs one
+  ($ENV{COMSPEC} =~ /cmd.exe$/i) ? 'start "HTML::Display" "%s"' : 'start "%s"'
+};
 
 1;
